==> nextcloud-26.0.11p1.tgz: nextcloud/apps/circles/l10n/mn.js <==
OC.L10N.register(
    "circles",
    {
    "Circles" : "Тойрог",
    "You joined {circle}" : "Та нэвтэрлээ {тойрогт}",
    "You left {circle}" : " Та гарлаа {тойрог} ",
    "Personal" : "Хувийн",
    "System" : "сисмем",
    "Open" : "Онгойлгох",
    "Hidden" : "Далд",
    "Federated" : "Federated",
    "Circle" : "Тойрог",
    "Member" : "Гишүүн",
    "Moderator" : "Шалгагч",
    "Admin" : "Админ",
    "Owner" : "Эзэмшигч",
    "Open »%s«" : "»%s« нээх",
    "Circle not found" : "тойрог олдоогүй",
    "This member does not exist" : "ийм гишүүн байхгүй байна",
    "You cannot join this circle" : "Та энэ тойрогт нэгдэх боломжгүй",
    "This member is not a moderator" : "Энэ гишүүн нь зохицуулагч биш",
    "This member is the owner of the circle" : "энэ гишүүн бүлгийн эзэн",
    "You are already a member of this circle" : "та аль хэдийн энэ тойргийн гишүүн болсон",
    "You have been blocked from this circle" : "та энэ тойргоос хасагдсан ",
    "Accept" : "Хүлээн зөвшөөрөх",
    "Personal Circle" : "хувийн тойрог",
    "You need a specify a type of circle" : "та тойргийн төрлийг тодорхойлах хэрэгтэй",
    "This member is not the owner of the circle" : "Энэ гишүүн нь бүлгийн эзэн биш",
    "You cannot edit level in a personal circle" : " та энэ хувийн тойргийн түвшинг засварлах боломжгүй",
    "No files in here" : "Энд файл алга",
    "No entries found in this folder" : "Энэ хавтаст юм олдсонгүй",
    "Name" : "Нэр",
    "Size" : "Хэмжээ",
    "Modified" : "Өөрчлөгдсөн"
},
"nplurals=2; plural=(n != 1);");

==> nextcloud-27.1.7p0.tgz: nextcloud/apps/circles/l10n/mn.js <==
OC.L10N.register(
    "circles",
    {
    "You joined {circle}" : "Та нэвтэрлээ {тойрогт}",
    "You left {circle}" : " Та гарлаа {тойрог} ",
    "Personal" : "Хувийн",
    "System" : "сисмем",
    "Open" : "Онгойлгох",
    "Password protected" : "Нууц үгээх хамгаалагдсан",
    "Hidden" : "Далд",
    "Federated" : "Federated",
    "Circle" : "Тойрог",
    "Member" : "Гишүүн",
    "Moderator" : "Шалгагч",
    "Admin" : "Админ",
    "Owner" : "Эзэмшигч",
    "Open »%s«" : "»%s« нээх",
    "This member is not a moderator" : "Энэ гишүүн нь зохицуулагч биш",
    "This member does not exist" : "ийм гишүүн байхгүй байна",
    "You are already a member of this circle" : "та аль хэдийн энэ тойргийн гишүүн болсон",
    "You have been blocked from this circle" : "та энэ тойргоос хасагдсан ",
    "Accept" : "Хүлээн зөвшөөрөх",
    "No files in here" : "Энд файл алга",
    "No entries found in this folder" : "Энэ хавтаст юм олдсонгүй",
    "Name" : "Нэр",
    "Size" : "Хэмжээ",
    "Modified" : "Өөрчлөгдсөн",
    "Circles" : "Тойрог",
    "Circle not found" : "тойрог олдоогүй",
    "You cannot join this circle" : "Та энэ тойрогт нэгдэх боломжгүй",
    "This member is the owner of the circle" : "энэ гишүүн бүлгийн эзэн",
    "Personal Circle" : "хувийн тойрог",
    "You need a specify a type of circle" : "та тойргийн төрлийг тодорхойлах хэрэгтэй",
    "This member is not the owner of the circle" : "Энэ гишүүн нь бүлгийн эзэн биш",
    "You cannot edit level in a personal circle" : " та энэ хувийн тойргийн түвшинг засварлах боломжгүй"
},
"nplurals=2; plural=(n != 1);");
